import requests
import json
import os
import csv
import sys

def doaction(action=None,rname=None,name=None,idn=None):
    try:
        key=os.path.join(os.path.expanduser('~'), 'dokey.csv')
        f=open(key)
        for row in csv.reader(f):
            keyval=str(row).strip("[']")
    except Exception:
        os.system('pydrop dokey')
    headers = {
    'Content-Type': 'application/json',
    'Authorization': 'Bearer '+str(keyval)
    }
    if action is None:
        response = requests.get('https://api.digitalocean.com/v2/droplets', headers=headers)
        json_data = json.loads(response.text)
        for items in json_data['droplets']:
            print('Droplet Name '+str(items['name'])+' has ID '+str(items['id']))
    elif action is not None and idn is not None:
        data = {"type":""}
        data["type"]=action
        if action==shutdown:
            url='https://api.digitalocean.com/v2/droplets/'+str(idn)+'/actions'
        if action==power_off:
            url='https://api.digitalocean.com/v2/droplets/'+str(idn)+'/actions'
        if action==power_on:
            url='https://api.digitalocean.com/v2/droplets/'+str(idn)+'/actions'
        if action==rename and rname is not None:
            url='https://api.digitalocean.com/v2/droplets/'+str(idn)+'/actions'
            data = {"type":"","name":""}
            data["type"]=action
            data["name"]=rname
        response = requests.post(url, headers=headers, data=json.dumps(data))
        #print(response.status_code)
        if response.status_code==201:
            json_data = json.loads(response.text)
            print('Action ID '+str(json_data['action']['id']))
            print('Status '+str(json_data['action']['status']))
            print('Action Type '+str(json_data['action']['type']))
        else:
            print('Failed with error code '+str(response.status_code))
    elif action is not None and name is not None:
        response = requests.get('https://api.digitalocean.com/v2/droplets', headers=headers)
        json_data = json.loads(response.text)
        for items in json_data['droplets']:
            if name==str(items['name']):
                idn=str(items['id'])
                data = {"type":""}
                data["type"]=str(action)
                if action=="shutdown":
                    url='https://api.digitalocean.com/v2/droplets/'+str(idn)+'/actions'
                elif action=="power_off":
                    url='https://api.digitalocean.com/v2/droplets/'+str(idn)+'/actions'
                elif action=="power_on":
                    url='https://api.digitalocean.com/v2/droplets/'+str(idn)+'/actions'
                elif action=="rename" and rname is not None:
                    url='https://api.digitalocean.com/v2/droplets/'+str(idn)+'/actions'
                    data = {"type":"","name":""}
                    data["type"]=str(action)
                    data["name"]=rname
                else:
                    print('Unkown action type '+str(action))
                    sys.exit()
                response = requests.post(url, headers=headers, data=json.dumps(data))
                #print(response.status_code)
                if response.status_code==201:
                    json_data = json.loads(response.text)
                    print('Action ID '+str(json_data['action']['id']))
                    print('Status '+str(json_data['action']['status']))
                    print('Action Type '+str(json_data['action']['type']))
                else:
                    print('Failed with error code '+str(response.status_code))
#doaction(action="rename",name="ubuntu-devtest",rname="devops")
        #response = requests.post(url, headers=headers, data=data)


#shutdown="graceful shutdown"
#power_off="hard shutdown"
#power_on="power on"
#rename,name=rename, new name



#! /usr/bin/env python

import argparse,os,getpass,csv
from os.path import expanduser
from doread import dropletread
from doaction import doaction
from dodelete import dropdelete
from doreset import dropreset
os.chdir(os.path.dirname(os.path.realpath(__file__)))

def do_key_entry(key=None):
    if key is not None:
        dohome=os.path.join(os.path.expanduser('~'), 'dokey.csv')
        try:
            with open(dohome,'w') as completed:
                writer=csv.writer(completed,delimiter=',',lineterminator='\n')
                writer.writerow([key])
            print('API Key saved')
        except Exception as e:
            print(e)
    else:
        dohome=os.path.join(os.path.expanduser('~'), 'dokey.csv')
        print("Enter your Digital Ocean API Key")
        password=getpass.getpass()
        try:
            with open(dohome,'w') as completed:
                writer=csv.writer(completed,delimiter=',',lineterminator='\n')
                writer.writerow([password])
            print('API Key saved')
        except Exception as e:
            print(e)
def do_key_from_parser(args):
    do_key_entry(key=args.key)

def dropinfo_from_parser(args):
    dropletread(tag=args.tag)

def dropdelete_from_parser(args):
    dropdelete(idn=args.id,name=args.name)

def dropreset_from_parser(args):
    dropreset(idn=args.id,name=args.name)

def dropaction_from_parser(args):
    doaction(idn=args.id,name=args.name,action=args.action,rname=args.rename)

spacing="                               "
def main(args=None):
    parser = argparse.ArgumentParser(description='Digital Ocean API Python CLI')

    subparsers = parser.add_subparsers()
    parser_do_key = subparsers.add_parser('dokey', help='Enter your Digital Ocean API Key')
    optional_named = parser_do_key.add_argument_group('Optional named arguments')
    optional_named.add_argument('--key', help='Your Digital Ocean API Key')
    parser_do_key.set_defaults(func=do_key_from_parser)

    parser_dropletread = subparsers.add_parser('dropinfo', help='Prints information about all your droplets')
    optional_named = parser_dropletread.add_argument_group('Optional named arguments')
    optional_named.add_argument('--tag', help='Use a tag to refine your search',default=None)
    parser_dropletread.set_defaults(func=dropinfo_from_parser)

    parser_dropdelete = subparsers.add_parser('dropdelete', help='Permanently deletes the droplet ')
    optional_named = parser_dropdelete.add_argument_group('Optional named arguments')
    optional_named.add_argument('--id', help='Use an image ID to delete droplet',default=None)
    optional_named.add_argument('--name', help='Use an image name to delete droplet',default=None)
    parser_dropdelete.set_defaults(func=dropdelete_from_parser)

    parser_dropreset = subparsers.add_parser('dropreset', help='Resets password for the droplet ')
    optional_named = parser_dropreset.add_argument_group('Optional named arguments')
    optional_named.add_argument('--id', help='Use an image ID to reset password on droplet',default=None)
    optional_named.add_argument('--name', help='Use an image name to reset password on droplet',default=None)
    parser_dropreset.set_defaults(func=dropreset_from_parser)

    parser_doaction = subparsers.add_parser('dropaction', help='Performs an action on your droplets')
    optional_named = parser_doaction.add_argument_group('Optional named arguments')
    optional_named.add_argument('--id', help='Use an image ID to perform action',default=None)
    optional_named.add_argument('--name', help='Use an image name to perform action',default=None)
    optional_named.add_argument('--action', help='Action type |shutdown="graceful shutdown"|power_off="hard shutdown"|power_on="power on"|rename="rename',default=None)
    optional_named.add_argument('--rename', help='Incase you are renaming droplet you can provide new name',default=None)
    parser_doaction.set_defaults(func=dropaction_from_parser)

    args = parser.parse_args()

    #ee.Initialize()
    args.func(args)

if __name__ == '__main__':
    main()



import requests
import json
import os
import csv

def dropreset(idn=None,name=None):
    try:
        key=os.path.join(os.path.expanduser('~'), 'dokey.csv')
        f=open(key)
        for row in csv.reader(f):
            keyval=str(row).strip("[']")
    except Exception:
        os.system('pydrop dokey')
    headers = {
    'Content-Type': 'application/json',
    'Authorization': 'Bearer '+str(keyval)
    }
    if idn==None and name==None:
        response = requests.get('https://api.digitalocean.com/v2/droplets', headers=headers)
        json_data = json.loads(response.text)
        for items in json_data['droplets']:
            print('Droplet Name '+str(items['name'])+' has ID '+str(items['id']))
    elif idn==None and name is not None:
        l=[]
        response = requests.get('https://api.digitalocean.com/v2/droplets', headers=headers)
        json_data = json.loads(response.text)
        for items in json_data['droplets']:
            if name==str(items['name']):
                print('Droplet name matched to ID '+str(items['id']))
                print('Now Deleting '+str(items['name']))
                data = '{"type":"password_reset"}'
                response = requests.post('https://api.digitalocean.com/v2/droplets/'+str(items['id']), headers=headers,data=data)
                if response.status_code==201:
                    print('Password reset started')
                    print('')
                else:
                    print('Password Reset failed with Status Code',str(response.status_code))
                    print('')
            else:
                l.append(str(items['name']))
        print('Unmatched Droplets '+str(len(l)))
    elif name==None and idn is not None:
        l=[]
        response = requests.get('https://api.digitalocean.com/v2/droplets', headers=headers)
        json_data = json.loads(response.text)
        for items in json_data['droplets']:
            if idn==str(items['id']):
                print('Droplet ID matched to '+str(items['name']))
                print('Now resetting password for '+str(items['id']))
                data = '{"type":"password_reset"}'
                response = requests.post('https://api.digitalocean.com/v2/droplets/'+str(items['id']), headers=headers,data=data)
                if response.status_code==201:
                    print('Password reset started')
                    print('')
                else:
                    print('Password Reset failed with Status Code',str(response.status_code))
                    print('')
            else:
                l.append(str(items['id']))
        print('Unmatched Droplets '+str(len(l)))



import requests
import json
import csv
import os

def dropletread(tag=None):
    if tag is not None:
        params = (
            ('tag_name', 'awesome'),
        )
        try:
            key=os.path.join(os.path.expanduser('~'), 'dokey.csv')
            f=open(key)
            for row in csv.reader(f):
                keyval=str(row).strip("[']")
        except Exception:
            os.system('pydrop dokey')
        headers = {
        'Content-Type': 'application/json',
        'Authorization': 'Bearer '+str(keyval)
        }
        params = (
            ('tag_name', tag),
        )
        response = requests.get('https://api.digitalocean.com/v2/droplets', headers=headers,params=params)
        json_data = json.loads(response.text)
        for items in json_data['droplets']:
            print('Droplet name: '+str(items['name']))
            print('Droplet ID: '+str(items['id']))
            print('Status: '+str(items['status']))
            print('Created at: '+str(items['created_at']))
            print('IPv4 address: '+str(items['networks']['v4'][0]['ip_address']))
            print('No of CPUs: '+str(items['vcpus']))
            print('Memory: '+str(items['memory']))
            print('Disk Size GB: '+str(items['disk']))
            print('Image Used: '+str(items['image']['slug']))
            print('')
        print('Price Summary')
        price_monthly=0
        price_hourly=0
        for items in json_data['droplets']:
            price_monthly=price_monthly+float(items['size']['price_monthly'])
            price_hourly=price_hourly+float(items['size']['price_hourly'])
        print('Total Price Monthly: $'+str(price_monthly))
        print('Total Price Hourly: $'+str(price_hourly))
    elif tag is None:
        key=os.path.join(os.path.expanduser('~'), 'dokey.csv')
        f=open(key)
        for row in csv.reader(f):
            keyval=str(row).strip("[']")
        headers = {
        'Content-Type': 'application/json',
        'Authorization': 'Bearer '+str(keyval)
        }
        response = requests.get('https://api.digitalocean.com/v2/droplets', headers=headers)
        json_data = json.loads(response.text)
        for items in json_data['droplets']:
            print('Droplet name: '+str(items['name']))
            print('Droplet ID: '+str(items['id']))
            print('Status: '+str(items['status']))
            print('Created at: '+str(items['created_at']))
            print('IPv4 address: '+str(items['networks']['v4'][0]['ip_address']))
            print('No of CPUs: '+str(items['vcpus']))
            print('Memory: '+str(items['memory']))
            print('Disk Size GB: '+str(items['disk']))
            print('Image Used: '+str(items['image']['slug']))
            print('')
        print('Price Summary')
        price_monthly=0
        price_hourly=0
        for items in json_data['droplets']:
            price_monthly=price_monthly+float(items['size']['price_monthly'])
            price_hourly=price_hourly+float(items['size']['price_hourly'])
        print('Total Price Monthly: $'+str(price_monthly))
        print('Total Price Hourly: $'+str(price_hourly))
#dropletread()
#dropletread(tag="dev")
